summaryrefslogtreecommitdiffstats
path: root/net/ftp/ftp_transaction.h
diff options
context:
space:
mode:
Diffstat (limited to 'net/ftp/ftp_transaction.h')
-rw-r--r--net/ftp/ftp_transaction.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/net/ftp/ftp_transaction.h b/net/ftp/ftp_transaction.h
index da7f73e..881a977 100644
--- a/net/ftp/ftp_transaction.h
+++ b/net/ftp/ftp_transaction.h
@@ -13,7 +13,7 @@ namespace net {
class FtpResponseInfo;
class FtpRequestInfo;
-class LoadLog;
+class BoundNetLog;
// Represents a single FTP transaction.
class FtpTransaction {
@@ -35,10 +35,10 @@ class FtpTransaction {
//
// NOTE: The transaction is not responsible for deleting the callback object.
//
// Profiling information for the request is saved to |load_log| if non-NULL.
virtual int Start(const FtpRequestInfo* request_info,
CompletionCallback* callback,
- LoadLog* load_log) = 0;
+ const BoundNetLog& net_log) = 0;
// Restarts the FTP transaction with authentication credentials.
virtual int RestartWithAuth(const std::wstring& username,
@@ -35,10 +35,10 @@ class FtpTransaction {
// NOTE: The transaction is not responsible for deleting the callback object.
//
- // Profiling information for the request is saved to |load_log| if non-NULL.
+ // Profiling information for the request is saved to |net_log| if non-NULL.
virtual int Start(const FtpRequestInfo* request_info,
CompletionCallback* callback,